# Installation

## Option 1: Install from PyPI

```bash
pip install srtk
```

## Option 2: Install from source

```bash
git clone https://github.com/happen2me/subgraph-retrieval-toolkit.git
cd subgraph-retrieval-toolkit
python install .
```
